@@ -8,6 +8,16 @@ from .utils import load_jobindex, expand_ids, load_jobfile
 
 JobListing = namedtuple('JobListing', ['job_id', 'task_id', 'jobname', 'command', 'tag'])
 
+def make_listing(jobid, task_id, jobname, command, tags, args):
+    listing = JobListing(jobid, task_id, jobname, command, tags)
+    if 'hide' in args and args.hide is not None:
+        listing = listing._asdict()
+        for field in JobListing._fields:
+            if field in args.hide:
+                listing[field] = '[hidden]'
+        listing = JobListing(**listing)
+    return listing
+
 def get_job_listings(args):
     def in_joblist(job_id):
         return True if args.jobid is None else job_id == args.jobid
@@ -27,12 +37,13 @@ def get_job_listings(args):
         for task_id in sorted(commands.keys()):
             if not in_tasklist(task_id):
                 continue
-            listing = JobListing(
+            listing = make_listing(
                 jobid,
                 task_id,
                 jobname,
                 repr(commands[task_id]),
-                tags[task_id]
+                tags[task_id],
+                args
             )
             job_list.append(listing)
     return job_list
