@@ -95,17 +95,24 @@ def meta_launch(args):
     os.makedirs(os.path.dirname(jobfile_path), exist_ok=True)
 
     if args.append:
-        jobs, tags = load_jobfile(jobfile_path)
-        start_jobid = max(jobs.keys()) + 1
+        cmds, tags = load_jobfile(jobfile_path)
+        start_jobid = max(cmds.keys()) + 1
+        jobs = {i: (cmds[i], tags[i]) for i in cmds.keys()}
     else:
         jobs = dict()
         start_jobid = 1
 
     if args.tag is not None:
-        tag_list = [
-            args.jobname + sep + '{}'.format(i) + suffix
-            for (i, suffix) in enumerate(cmd_suffix_list, start_jobid)
-        ]
+        if args.no_tag_number:
+            tag_list = [args.jobname + suffix for suffix in cmd_suffix_list]
+        else:
+            n_digits = len(str(start_jobid + len(cmd_suffix_list) - 1))
+            tag_number_format = '{{:0{0}d}}'.format(n_digits)
+            tag_list = [
+                args.jobname + sep + tag_number_format.format(i) + suffix
+                for (i, suffix) in enumerate(cmd_suffix_list, start_jobid)
+            ]
+
         cmd_prefix_list = [
             ' '.join([prefix, args.tag, suffix])
             for (prefix, suffix) in zip(cmd_prefix_list, tag_list)
