@@ -1,4 +1,5 @@
 from contextlib import ExitStack
+from datetime import datetime
 import subprocess
 import sys
 
@@ -7,7 +8,8 @@ from .utils import load_jobfile
 def run_command_by_id(commands, task_id, stdout=None, stderr=None, quiet=False):
     cmd = commands[task_id]
     if not quiet:
-        print('Launching worker:', cmd)
+        print('Launching worker: {}'.format(cmd), flush=True)
+        start_time = datetime.now()
     with ExitStack() as stack:
         stdout = stack.enter_context(open(stdout, 'wb')) if stdout is not None else None
         stderr = stack.enter_context(open(stderr, 'wb')) if stderr is not None else None
@@ -17,11 +19,12 @@ def run_command_by_id(commands, task_id, stdout=None, stderr=None, quiet=False):
             raise
         else:
             if not quiet:
-                print('Worker finished:', cmd)
+                elapsed = datetime.now() - start_time
+                print('Worker finished: {}\nElapsed time:  {}'.format(cmd, elapsed), flush=True)
 
 if __name__ == '__main__':
     assert len(sys.argv) == 3, 'Usage: python -m worker path/to/commands.json task_id'
-    
+
     commands_file = sys.argv[1]
     task_id = int(sys.argv[2])
 
